//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: 26 December 1997
// Last Modified: 16 February 1998
// Filename:      ...sig/examples/sigmidi/improv/batonImprov/note2.cc
// Syntax:        C++; Radio Baton Improv
//  
// Description: Plays a note when a baton stick is triggered
//	Both sticks behave the same.  Only one note at a time.
//	Unlike the note.cpp program, this program maps the
//	x-axis to pitch.  Whack is mapped to attack velocity.
//

#include "batonImprov.h" 


/*----------------- beginning of improvization algorithms ---------------*/

int note1;       // the current note being played (keep track for turning off).
int note2;       // the current note being played on stick 2
int instrument;  // the current instrument being played on

/*--------------------- maintenance algorithms --------------------------*/

void description(void) {
   cout << endl;
   cout << "This program demonstrates how to play notes with baton triggers.\n";
   cout << "Only one pitch is played at a time.\n";
   cout << endl;
   cout << "The b14+ and b15+ buttons control the instrument being played.\n";
   cout << endl;
   cout << "Press the key \"X\" to turn on the MIDI out trace and see what\n";
   cout << "MIDI commands are being sent to the synthesizer.\n";
   cout << endl;
}

void initialization(void) { 
   note1 = note2 = 0;
   instrument = 0;
   synth.pc(CH_1, instrument);
}

void finishup(void) { }


/*-------------------- main loop algorithms -----------------------------*/

void mainloopalgorithms(void) { }


/*-------------------- triggered algorithms -----------------------------*/

void stick1trig(void) { 
   cout << "Stick 1 triggered:  xw1 = " << xw1 << " yw1 = " << yw1 
        << " wh1 = " << wh1 << endl;
   synth.play(CH_1, note1, 0);
   note1 = xw1;
   synth.play(CH_1, note1, yw1);
}

void stick2trig(void) { 
   cout << "Stick 2 triggered: xw2 = " << xw2 << " yw2 = " << yw2 
        << " wh2 = " << wh2 << endl;
   synth.play(CH_1, note2, 0);
   note2 = xw2;
   synth.play(CH_1, note2, yw2);
}

void b14plustrig(void) {
   instrument++;
   if (instrument > 127)  instrument = 127;
   synth.pc(CH_1, instrument);
   cout << "instrument = " << instrument << endl;
}

void b15plustrig(void) { 
   instrument--;
   if (instrument < 0)  instrument = 0;
   synth.pc(CH_1, instrument);
   cout << "instrument = " << instrument << endl;
}

void b14minusuptrig(void) { }

void b14minusdowntrig(void) { }

void b15minusuptrig(void) { }

void b15minusdowntrig(void) { }

void keyboardchar(int key) { charsynth(key); }


/*------------------ end improvization algorithms -----------------------*/


