//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: Sun Dec 28 15:04:24 GMT-0800 1997
// Last Modified: Fri Jan 23 10:56:18 GMT-0800 1998
// Filename:      ...sig/code/control/MidiOutPort/MidiOutPort.h
// Syntax:        C++ 
//

#ifndef _MIDIOUTPORT_H_INCLUDED
#define _MIDIOUTPORT_H_INCLUDED


#define MIDIOUTPORT(system)   MidiOutPort_ ## system

#ifdef VISUAL
   #define sys    visual
   #include "MidiOutPort_visual.h"
#else
   #define sys    unsupported
   #include "MidiOutPort_unsupported.h"
#endif


#ifdef VISUAL
class MidiOutPort : protected MIDIOUTPORT(visual) {
   public:
                  MidiOutPort        (void) : MIDIOUTPORT(visual)() {}
                  MidiOutPort        (int aPort, int autoOpen = 1) : 
                                         MIDIOUTPORT(visual)(aPort, autoOpen) {}
                 ~MidiOutPort()      { }

      void        close(void)        { MIDIOUTPORT(visual)::close(); }
      void        closeAll(void)     { MIDIOUTPORT(visual)::closeAll(); }
      const char* getName(void)      { return MIDIOUTPORT(visual)::getName(); }
      int         getNumPorts(void) { 
                     return MIDIOUTPORT(visual)::getNumPorts(); }
      int         getPort(void)      { return MIDIOUTPORT(visual)::getPort(); }
      int         getPortStatus(void) { 
                     return MIDIOUTPORT(visual)::getPortStatus(); }
      int         getTrace(void) { 
                     return MIDIOUTPORT(visual)::getTrace(); }
      int         open(void)         { return MIDIOUTPORT(visual)::open(); }
      int         rawsend(int command, int p1, int p2) {
                     return MIDIOUTPORT(visual)::rawsend(command, p1, p2); }
      int         rawsend(int command, int p1) {
                     return MIDIOUTPORT(visual)::rawsend(command, p1); }
      int         rawsend(int command) {
                     return MIDIOUTPORT(visual)::rawsend(command); }
      int         rawsend(uchar array, int size) {
                     return MIDIOUTPORT(visual)::rawsend(array, size); }
      void        setPort(int aPort) { MIDIOUTPORT(visual)::setPort(aPort); }
      int         setTrace(int aState) {
                     return MIDIOUTPORT(visual)::setTrace(aState); }
      void        toggleTrace(void) { MIDIOUTPORT(visual)::toggleTrace(); }
};
#else 
class MidiOutPort : protected MIDIOUTPORT(unsupported) {
   public:
                  MidiOutPort        (void) : MIDIOUTPORT(unsupported)() {}
                  MidiOutPort        (int aPort, int autoOpen = 1) : 
                                         MIDIOUTPORT(unsupported)(aPort, 
                                            autoOpen) {}
                 ~MidiOutPort()      { }

      void        close(void)        { MIDIOUTPORT(unsupported)::close(); }
      void        closeAll(void)     { MIDIOUTPORT(unsupported)::closeAll(); }
      const char* getName(void) { 
                     return MIDIOUTPORT(unsupported)::getName(); }
      int         getNumPorts(void) { 
                     return MIDIOUTPORT(unsupported)::getNumPorts(); }
      int         getPort(void) {
                     return MIDIOUTPORT(unsupported)::getPort(); }
      int         getPortStatus(void) { 
                     return MIDIOUTPORT(unsupported)::getPortStatus(); }
      int         getTrace(void) { 
                     return MIDIOUTPORT(unsupported)::getTrace(); }
      int         open(void) {
                     return MIDIOUTPORT(unsupported)::open(); }
      int         rawsend(int command, int p1, int p2) {
                     return MIDIOUTPORT(unsupported)::rawsend(command, p1, p2);}
      int         rawsend(int command, int p1) {
                     return MIDIOUTPORT(unsupported)::rawsend(command, p1); }
      int         rawsend(int command) {
                     return MIDIOUTPORT(unsupported)::rawsend(command); }
      int         rawsend(uchar array, int size) {
                     return MIDIOUTPORT(unsupported)::rawsend(array, size); }
      void        setPort(int aPort) { 
                     MIDIOUTPORT(unsupported)::setPort(aPort); }
      int         setTrace(int aState) {
                     return MIDIOUTPORT(unsupported)::setTrace(aState); }
      void        toggleTrace(void) {
                     MIDIOUTPORT(unsupported)::toggleTrace(); }
};
#endif



#endif  // _MIDIOUTPORT_H_INCLUDED


