//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: 19 December 1997
// Last Modified: Fri Jan 23 00:26:12 GMT-0800 1998
// Filename:      ...sig/code/control/MidiMessage/MidiMessage.cpp
// Syntax:        C++ 
// $Smake:        cc -g -c %f -I../../../include && rm -f %b.o
//
// Description: A structure for handling MIDI input messages.
//

#include "MidiMessage.h"


//////////////////////////////
//
// MidiMessage::MidiMessage
//

MidiMessage::MidiMessage(void) {
   // no initialization
}


// default value aTime = 0
MidiMessage::MidiMessage(int aCommand, int aP1, int aP2, int aTime) {
   time = aTime;
   command() = aCommand;
   p1() = aP1;
   p2() = aP2;
}


MidiMessage::MidiMessage(const MidiMessage& aMessage) {
   time = aMessage.time;
   data = aMessage.data;
}



//////////////////////////////
//
// MidiMessage::~MidiMessage -- Destructor.
//

MidiMessage::~MidiMessage() {
   // do nothing
}



//////////////////////////////
//
// MidiMessage::command -- returns the MIDI command byte
//

uchar& MidiMessage::command(void) {
   return *(((uchar*)&data)+0);
}



//////////////////////////////
//
// MidiMessage::operator= -- defines how objects are to be copied
//

MidiMessage& MidiMessage::operator=(const MidiMessage& aMessage) {
   time = aMessage.time;
   data = aMessage.data;
   return *this;
}



//////////////////////////////
//
// MidiMessage::p1 -- returns the first parameter of the
//    midi message.  Valid if the command requires a parameter.
//

uchar& MidiMessage::p1(void) {
   return *(((uchar*)&data)+1);
}



//////////////////////////////
//
// MidiMessage::p2 -- returns the second parameter of the
//    midi message.  Valid if the command requires two parameters.
//

uchar& MidiMessage::p2(void) {
   return *(((uchar*)&data)+2);
}


//////////////////////////////
//
// MidiMessage::p3 -- returns the third parameter of the
//    midi message.  Valid if the command requires three parameters
//    (but none of the MIDI command do).
//

uchar& MidiMessage::p3(void) {
   return *(((uchar*)&data)+3);
}


